<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns="http://www.osoa.org/xmlns/sca/1.0"
  xmlns:system="http://tuscany.apache.org/xmlns/system/1.0-SNAPSHOT"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:sca="http://www.osoa.org/xmlns/sca/1.0"
  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
  xmlns:wsdli="http://www.w3.org/2006/01/wsdl-instance">
  <xsl:output method="xml" indent="yes" />

  <xsl:param name="ref" select="''" />
  <xsl:param name="interface" />
  <xsl:param name="wsdllocation" />
  <xsl:param name="location" />
  <xsl:param name="endpoint" />

  <xsl:template match="* | node()">
    <xsl:copy>
      <xsl:apply-templates select="@*" />
      <xsl:apply-templates />
    </xsl:copy>
  </xsl:template>

  <xsl:template match="@*">
    <xsl:attribute name="{name()}">
      <xsl:value-of select="." />
    </xsl:attribute>
  </xsl:template>

  <xsl:template match="/sca:composite/sca:reference">
    <!-- select reference for interface and binding change -->
    <xsl:choose>
      <xsl:when test="$ref = @name">
        <!-- copy reference -->
        <xsl:copy>
          <xsl:apply-templates select="@*" />
          <!-- add service interface definition -->
          <xsl:if test="$interface">
            <xsl:element name="interface.wsdl">
              <xsl:attribute name="interface">
                <xsl:value-of select="$interface" />
              </xsl:attribute>
              <xsl:if test="$wsdllocation">
              <xsl:attribute name="wsdli:wsdlLocation"
                namespace="http://www.w3.org/2006/01/wsdl-instance">
                <xsl:value-of select="$wsdllocation" />
              </xsl:attribute>
              </xsl:if>
            </xsl:element>
          </xsl:if>
          <!-- add service binding definition -->
          <xsl:element name="binding.ws">
            <xsl:if test="$location">
            <xsl:attribute name="location">
              <xsl:value-of select="$location" />
            </xsl:attribute>
            </xsl:if>
            <xsl:if test="$endpoint">
            <xsl:attribute name="endpoint">
              <xsl:value-of select="$endpoint" />
            </xsl:attribute>
            </xsl:if>
          </xsl:element>
        </xsl:copy>
      </xsl:when>
      <xsl:otherwise>
        <!-- copy reference without interface and binding change -->
        <xsl:copy>
          <xsl:apply-templates select="@* | node()" />
        </xsl:copy>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="/sca:composite/sca:service">
    <!-- select reference for interface and binding change -->
    <xsl:choose>
      <xsl:when test="$ref = @name">
        <!-- copy reference -->
        <xsl:copy>
          <xsl:apply-templates select="@*" />
          <!-- add service interface definition -->
          <xsl:if test="$interface">
            <xsl:element name="interface.wsdl">
              <xsl:attribute name="interface">
                <xsl:value-of select="$interface" />
              </xsl:attribute>
              <xsl:if test="$wsdllocation">
              <xsl:attribute name="wsdli:wsdlLocation"
                namespace="http://www.w3.org/2006/01/wsdl-instance">
                <xsl:value-of select="$wsdllocation" />
              </xsl:attribute>
              </xsl:if>
            </xsl:element>
          </xsl:if>
          <!-- add service binding definition -->
          <xsl:element name="binding.ws">
            <xsl:if test="$location">
            <xsl:attribute name="location">
              <xsl:value-of select="$location" />
            </xsl:attribute>
            </xsl:if>
            <xsl:if test="$endpoint">
            <xsl:attribute name="endpoint">
              <xsl:value-of select="$endpoint" />
            </xsl:attribute>
            </xsl:if>
          </xsl:element>
        </xsl:copy>
      </xsl:when>
      <xsl:otherwise>
        <!-- copy reference without interface and binding change -->
        <xsl:copy>
          <xsl:apply-templates select="@* | node()" />
        </xsl:copy>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  

</xsl:stylesheet>